# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: corpus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='corpus.proto',
  package='',
  serialized_pb=_b('\n\x0c\x63orpus.proto\"c\n\x07\x45xample\x12\r\n\x05words\x18\x01 \x03(\t\x12!\n\x07trigger\x18\x02 \x03(\x0b\x32\x10.Example.Trigger\x1a&\n\x07Trigger\x12\n\n\x02id\x18\x01 \x02(\x05\x12\x0f\n\x07trigger\x18\x02 \x02(\t\"#\n\x06\x43orpus\x12\x19\n\x07\x65xample\x18\x01 \x03(\x0b\x32\x08.Example')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_EXAMPLE_TRIGGER = _descriptor.Descriptor(
  name='Trigger',
  full_name='Example.Trigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Example.Trigger.id', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='Example.Trigger.trigger', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=115,
)

_EXAMPLE = _descriptor.Descriptor(
  name='Example',
  full_name='Example',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='words', full_name='Example.words', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='Example.trigger', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_EXAMPLE_TRIGGER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16,
  serialized_end=115,
)


_CORPUS = _descriptor.Descriptor(
  name='Corpus',
  full_name='Corpus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='example', full_name='Corpus.example', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=152,
)

_EXAMPLE_TRIGGER.containing_type = _EXAMPLE
_EXAMPLE.fields_by_name['trigger'].message_type = _EXAMPLE_TRIGGER
_CORPUS.fields_by_name['example'].message_type = _EXAMPLE
DESCRIPTOR.message_types_by_name['Example'] = _EXAMPLE
DESCRIPTOR.message_types_by_name['Corpus'] = _CORPUS

Example = _reflection.GeneratedProtocolMessageType('Example', (_message.Message,), dict(

  Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), dict(
    DESCRIPTOR = _EXAMPLE_TRIGGER,
    __module__ = 'corpus_pb2'
    # @@protoc_insertion_point(class_scope:Example.Trigger)
    ))
  ,
  DESCRIPTOR = _EXAMPLE,
  __module__ = 'corpus_pb2'
  # @@protoc_insertion_point(class_scope:Example)
  ))
_sym_db.RegisterMessage(Example)
_sym_db.RegisterMessage(Example.Trigger)

Corpus = _reflection.GeneratedProtocolMessageType('Corpus', (_message.Message,), dict(
  DESCRIPTOR = _CORPUS,
  __module__ = 'corpus_pb2'
  # @@protoc_insertion_point(class_scope:Corpus)
  ))
_sym_db.RegisterMessage(Corpus)


# @@protoc_insertion_point(module_scope)



import sqlite3

def create_schema(conn, schema, table_name):
    symbolic_assignment = ", ".join([name + "=?" for name, row_type in schema])
    symbolic_values = "(" + ", ".join(["?"] * (1 + len(schema))) + ")"

    insert_string = "INSERT into %s values %s"    % (table_name, symbolic_values)
    update_string = "UPDATE %s SET %s WHERE id=?" % (table_name, symbolic_assignment)
    update_string_lines = "UPDATE %s SET lines=? WHERE id=?" % (table_name,)
    select_string = "SELECT * FROM %s WHERE id=?" % (table_name,)
    select_string_lines = "SELECT lines FROM %s WHERE id=?" % (table_name,)
    #lines pickle, parents pickle

    cursor = conn.cursor()
    schema_definition = ", \n".join([name + " " + row_type for name, row_type in schema])

    try:
        cursor.execute("""
            CREATE TABLE %s (
                id    integer primary key not null,
                %s
                )""" % (table_name, schema_definition))
    except sqlite3.OperationalError:
        pass

    def insert_into_db(obj):
        try:
            cursor.execute(
                insert_string,
                obj
            )
            conn.commit()
        except sqlite3.IntegrityError:
            print(obj)

    def update_in_db(obj):
        cursor.execute(update_string,
            obj
        )
        conn.commit()

    def update_lines_in_db(obj):
        cursor.execute(update_string_lines,
            obj
        )
        conn.commit()

    def get_obj_from_db(key):
        cursor.execute(select_string, (key,))
        data = cursor.fetchone()
        return data

    def get_lines_from_db(key):
        cursor.execute(select_string_lines, (key,))
        data = cursor.fetchone()
        return data

    return (insert_into_db, update_in_db, update_lines_in_db, get_obj_from_db, get_lines_from_db)

from .sqlite_proto_buff import corpus_pb2

def convert_examples_to_protobuff(legacy):
    corpus = corpus_pb2.Corpus()
    for example in legacy:
        ex = corpus.example.add()
        ex.words.extend(example[0])
        triggers = example[1]
        for trigger_id, trigger_text in triggers:
            trig = ex.trigger.add()
            trig.id = trigger_id
            trig.trigger = trigger_text
    return corpus

def deserialize_protobuf(blob):
    corpus = corpus_pb2.Corpus()
    corpus.ParseFromString(blob)
    return corpus

def serialize_protobuf(corpus):
    return corpus.SerializeToString()
